# -*- coding: utf-8 -*-
from datetime import datetime
from pprint import pprint

import requests

URL = 'http://iss-positioner.nkoshelev.pro/radius'

# Crimea
lon, lat = 34.6, 45.2

objects = [
    {'title': 'Crimea', 'lon': lon, 'lat': lat},
    {'title': 'Ozero Baikal', 'lon': 107.75, 'lat': 53.216},
    {'title': 'Lednik Davidova', 'lon': 78.15, 'lat': 41.86},
]

now = datetime.utcnow()


def get(params):
    start = datetime.utcnow()
    resp = requests.post(URL, json=params)
    result = resp.json()
    print(datetime.utcnow() - start)
    if result['error']:
        return
    return result['data']


def main():
    params_one = dict(start_dt=now.isoformat(), end_dt='2017-07-14', lat=lat, lon=lon, min_duration=30)
    result_one = get(params_one)
    print('One\n---')
    pprint(result_one)
    params_many = dict(start_dt=now.isoformat(), end_dt='2017-07-14', objects=objects, min_duration=30)
    result_many = get(params_many)
    print('Many\n----')
    pprint(result_many)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
import asyncio
from datetime import datetime

from aiohttp import ClientSession

URL = 'http://iss-positioner.nkoshelev.pro/lst'

PARAMS = dict(start_dt='2017-06-12',
              end_dt='2017-07-07 17:20:22',
              dist='250',
              units='km',
              min_duration='30',
              lst=open('uragan.lst', 'rb'))


async def main(loop):
    start = datetime.utcnow()
    async with ClientSession(loop=loop) as session:
        async with session.post(URL, data=PARAMS) as resp:
            result = await resp.json()
            print(datetime.utcnow() - start)

            if result['error']:
                return

            for title, coords_set in result['data'].items():
                print()
                print(title)
                print('-' * len(title))
                for coords in coords_set:
                    print('Session duration', len(coords), 'Traverz:', min(coords, key=lambda c: c['dist']))


if __name__ == '__main__':
    loop = asyncio.get_event_loop()

    try:
        loop.run_until_complete(main(loop))
    finally:
        loop.close()



# -*- coding: utf-8 -*-
import math
from collections import defaultdict
from datetime import datetime
from itertools import groupby

import ephem
import requests
from pytz import timezone
from pytz.exceptions import UnknownTimeZoneError
from timezonefinder import TimezoneFinder

tf = TimezoneFinder()


def find_timezone(lat, lng):
    lat = float(lat)
    lng = float(lng)

    try:
        timezone_name = tf.timezone_at(lng=lng, lat=lat)
        if timezone_name is None:
            timezone_name = tf.closest_timezone_at(lng=lng, lat=lat)
            # maybe even increase the search radius when it is still None

    except ValueError:
        # the coordinates were out of bounds
        # {handle error}
        raise
    else:
        print(timezone_name)
        return timezone_name


def localize_dt(utc_datetime, timezone_name):
    try:
        tz = timezone(timezone_name)
        localized_dt = tz.fromutc(utc_datetime)
    except UnknownTimeZoneError:
        # ... handle the error ...
        raise
    else:
        return localized_dt


URL = 'http://iss-positioner.nkoshelev.pro/lst'
# URL = 'http://localhost:8081/lst'

PARAMS = dict(start_dt='2017-06-15',
              end_dt='2017-07-16',
              dist='155',
              units='km',
              min_duration='1')
FILES = dict(lst=open('uragan.lst', 'rb'))


def sun_angle(dt, longitude=None, latitude=None, body=ephem.Sun()):
    obs = ephem.Observer()
    obs.long, obs.lat, obs.date = math.radians(longitude), math.radians(latitude), dt
    body.compute(obs)
    return math.degrees(body.alt)


def main():
    start = datetime.utcnow()
    resp = requests.post(URL, data=PARAMS, files=FILES)
    result = resp.json()
    print(datetime.utcnow() - start)

    if result['error']:
        return

    session = defaultdict(list)
    for title, coords_set in result['data'].items():
        for coords in coords_set:
            session[coords[len(coords)//2]['dt'][:10]].append([dict(title=title, **coord) for coord in coords])

    for dt, coords_set in sorted(session.items(), key=lambda item: item[0]):
        coords_set.sort(key=lambda cs: (cs[0]['dt'], cs[0]['title']))
        print()
        print(dt)
        print('-' * len(dt))
        print('Sun\tstart\tend\tTraverz')
        for coords in coords_set:
            start, traverz, end = coords[0]['dt'], min(coords, key=lambda c: c['dist']), coords[-1]['dt']
            sa = sun_angle(traverz['dt'], **traverz['coord'])
            if 1 < sa < 90:
                print('%s\t%s\t%s\t%s' % (sa, start, end, traverz))


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
import asyncio
from datetime import datetime
from pprint import pprint

from aiohttp import ClientSession

URL = 'http://iss-positioner.nkoshelev.pro/radius'

# Crimea
lon, lat = 34.6, 45.2

objects = [
    {'title': 'Crimea', 'lon': lon, 'lat': lat},
    {'title': 'Ozero Baikal', 'lon': 107.75, 'lat': 53.216},
    {'title': 'Lednik Davidova', 'lon': 78.15, 'lat': 41.86},
]

now = datetime.utcnow()


async def get(session, params):
    start = datetime.utcnow()
    async with session.post(URL, json=params) as resp:
        result = await resp.json()
    print(datetime.utcnow() - start)
    if result['error']:
        return
    return result['data']


async def main(loop):
    params_one = dict(start_dt=now.isoformat(), end_dt='2017-07-14', lat=lat, lon=lon, min_duration=30)
    params_many = dict(start_dt=now.isoformat(), end_dt='2017-07-14', objects=objects, min_duration=30)
    async with ClientSession(loop=loop) as session:
        result_one, result_many = await asyncio.gather(get(session, params_one), get(session, params_many), loop=loop)
    print('One\n---')
    pprint(result_one)
    print('Many\n----')
    pprint(result_many)


if __name__ == '__main__':
    loop = asyncio.get_event_loop()

    try:
        loop.run_until_complete(main(loop))
    finally:
        loop.close()
